Received: from localhost (unknown [200.46.204.183]) by developer.postgresql.org (Postfix) with ESMTP id 3685E2E0046 for ; Fri, 20 Jun 2008 07:24:24 -0300 (ADT) Received: from developer.postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.204.183]) (amavisd-maia, port 10024) with ESMTP id 49783-06 for ; Fri, 20 Jun 2008 07:24:15 -0300 (ADT) X-Greylist: from auto-whitelisted by SQLgrey-1.7.6 Received: from mailrelay.edis.at (mailrelay.edis.at [81.223.48.5]) by developer.postgresql.org (Postfix) with ESMTP id 28F642E0040 for ; Fri, 20 Jun 2008 07:24:18 -0300 (ADT) Received: from [91.83.13.22] (91.83.13.22.pool.invitel.hu [::ffff:91.83.13.22]) (AUTH: CRAM-MD5 zb@cybertec.at, TLS: TLSv1/SSLv3,256bits,AES256-SHA) by mailrelay.edis.at with esmtp; Fri, 20 Jun 2008 12:24:14 +0200 id 000F24DC.485B854E.000033F5 Message-ID: <485B854D.1050200@cybertec.at> Date: Fri, 20 Jun 2008 12:24:13 +0200 From: Zoltan Boszormenyi User-Agent: Thunderbird 2.0.0.14 (X11/20080501) MIME-Version: 1.0 To: Greg Smith CC: Hans-Juergen Schoenig , pgsql-patches Subject: Re: posix advises ... References: <4826C200.8060807@cybertec.at> <485A3F20.1080907@cybertec.at> In-Reply-To: X-Enigmail-Version: 0.95.6 Content-Type: text/plain; charset=ISO-8859-1 Content-Transfer-Encoding: 8bit X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200806/128 X-Sequence-Number: 6614 Greg Smith írta: > On Thu, 19 Jun 2008, Zoltan Boszormenyi wrote: > >> This patch (revisited and ported to current CVS HEAD) is indeed using >> Greg's original patch and also added another patch written by Mark Wong >> that helps evicting closed XLOGs from memory faster. > > Great, that will save me some trouble. I've got a stack of Linux > performance testing queued up (got stuck behind a kernel bug impacting > pgbench) for the next couple of weeks and I'll include this in that > testing. I think I've got a similar class of hardware as you tested > on for initial evaluation--I'm getting around 200MB/s sequential I/O > right now out of my small RAID setup,. > > I added your patch to the queue for next month's CommitFest and listed > myself as the initial reviewer, but a commit that soon is unlikely. > Performance tests like this usually take a while to converge, and > since this is using a less popular API I expect a round of portability > concerns, too. > > Where did Marc's patch come from? I'd like to be able to separate out > that change from the rest if necessary. That patch was posted here: http://archives.postgresql.org/pgsql-patches/2008-03/msg00000.php > Also, if you have any specific test cases you ran that I could start > by trying to replicate a speedup on, those would be handy as well. We experienced synchronized seqscans slowing down after some (10+) clients which seems to be strange as it should be a strong selling point of 8.3. With the posix_fadvise() patchs, the dropoff was pushed further. The query involved multiple tables, it was not a trivial one table seqscan case. Without the patch, both a simpler SATA system (each disk at ~63MB/sec) and a hw RAID with 400+ MB/sec showed slowdown. The initial 60-63MB/sec with 1-3 clients on the single SATA disk system quickly dropped to 11-17MB/sec with more clients. With the patch, it only dropped to 40-47MB/sec. I cannot recall the RAID figures. > -- > * Greg Smith gsmith@gregsmith.com http://www.gregsmith.com Baltimore, MD > -- ---------------------------------- Zoltán Böszörményi Cybertec Schönig & Schönig GmbH http://www.postgresql.at/